@@ -91,13 +91,14 @@ import os
 import re
 import sys
 
+import codecs
 import tempfile
 import subprocess as sp
 
 from datetime import date, datetime
 
 __pkgname__ = 'python-crontab'
-__version__ = '1.8.1'
+__version__ = '1.8.2'
 
 ITEMREX = re.compile(r'^\s*([^@#\s]+)\s+([^@#\s]+)\s+([^@#\s]+)\s+([^@#\s]+)'
                      r'\s+([^@#\s]+)\s+([^#\n]*)(\s+#\s*([^\n]*)|$)')
@@ -137,9 +138,6 @@ SYSTEMV = SYSTEMV or os.getenv('SYSTEMV_TEST')
 
 TESTING = False
 CRONCMD = "/usr/bin/crontab"
-if sys.argv[0].startswith('test_'):
-    TESTING = True
-    CRONCMD = './data/crontest'
 
 try:
     import pwd
@@ -229,7 +227,7 @@ class CronTab(object):
             lines = self.intab.split('\n')
         elif filename:
             self.filen = filename
-            with open(filename, 'r') as fhl:
+            with codecs.open(filename, 'r', encoding='utf-8') as fhl:
                 lines = fhl.readlines()
         else:
             (out, err) = pipeOpen(CRONCMD, l='', u=self.user).communicate()
